# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/grpc/hdmaplib.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2
from proto.hdmap_lib.proto import lane_pb2 as proto_dot_hdmap__lib_dot_proto_dot_lane__pb2
from proto.hdmap_lib.proto import junction_pb2 as proto_dot_hdmap__lib_dot_proto_dot_junction__pb2
from proto.hdmap_lib.proto import object_pb2 as proto_dot_hdmap__lib_dot_proto_dot_object__pb2
from proto.hdmap_lib.proto import poi_pb2 as proto_dot_hdmap__lib_dot_proto_dot_poi__pb2
from proto.hdmap_lib.proto import parking_space_pb2 as proto_dot_hdmap__lib_dot_proto_dot_parking__space__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/grpc/hdmaplib.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=b'\n\031io.grpc.examples.hdmaplibB\rHdmapLibProtoP\001\242\002\003HDL',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19proto/grpc/hdmaplib.proto\x12\thdmap_lib\x1a$proto/hdmap_lib/proto/geometry.proto\x1a proto/hdmap_lib/proto/lane.proto\x1a$proto/hdmap_lib/proto/junction.proto\x1a\"proto/hdmap_lib/proto/object.proto\x1a\x1fproto/hdmap_lib/proto/poi.proto\x1a)proto/hdmap_lib/proto/parking_space.proto\";\n\rGetMapRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x16\n\x0e\x62usiness_scene\x18\x02 \x01(\t\"\xc8\x01\n\rLaneArrowData\x12\x0f\n\x07heading\x18\x01 \x01(\x01\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\x12\x35\n\nturn_types\x18\x04 \x03(\x0e\x32!.hdmap_lib.LaneArrowData.Turntype\"Y\n\x08Turntype\x12\x0b\n\x07NO_TURN\x10\x01\x12\r\n\tLEFT_TURN\x10\x02\x12\x0e\n\nRIGHT_TURN\x10\x03\x12\x0f\n\x0bLEFT_U_TURN\x10\x04\x12\x10\n\x0cRIGHT_U_TURN\x10\x05\"m\n\x0cPolygonArrow\x12(\n\x06points\x18\x01 \x01(\x0b\x32\x18.hdmap_lib.PolygonPoints\x12\x10\n\x08\x63\x65nter_x\x18\x02 \x01(\x01\x12\x10\n\x08\x63\x65nter_y\x18\x03 \x01(\x01\x12\x0f\n\x07heading\x18\x04 \x01(\x01\"\x96\x01\n\x07PoiArea\x12(\n\x06points\x18\x01 \x01(\x0b\x32\x18.hdmap_lib.PolygonPoints\x12\x10\n\x08poi_name\x18\x02 \x01(\t\x12\t\n\x01x\x18\x03 \x01(\x01\x12\t\n\x01y\x18\x04 \x01(\x01\x12\x0f\n\x07heading\x18\x05 \x01(\x01\x12(\n\x08poi_type\x18\x06 \x01(\x0e\x32\x16.hdmap_lib.Poi.PoiType\"\x94\n\n\x0bMapElements\x12\x30\n\x05lanes\x18\x01 \x03(\x0b\x32!.hdmap_lib.MapElements.LanesEntry\x12\x38\n\tjunctions\x18\x02 \x03(\x0b\x32%.hdmap_lib.MapElements.JunctionsEntry\x12\x30\n\x05lines\x18\x03 \x03(\x0b\x32!.hdmap_lib.MapElements.LinesEntry\x12\x34\n\x07objects\x18\x04 \x03(\x0b\x32#.hdmap_lib.MapElements.ObjectsEntry\x12.\n\x04pois\x18\x05 \x03(\x0b\x32 .hdmap_lib.MapElements.PoisEntry\x12\x42\n\x0eLaneArrowdatas\x18\x06 \x03(\x0b\x32*.hdmap_lib.MapElements.LaneArrowdatasEntry\x12\x46\n\x10PoiLaneRelations\x18\x07 \x03(\x0b\x32,.hdmap_lib.MapElements.PoiLaneRelationsEntry\x12-\n\x0b\x61rrow_lanes\x18\x08 \x03(\x0b\x32\x18.hdmap_lib.LaneArrowData\x12%\n\tpoi_areas\x18\t \x03(\x0b\x32\x12.hdmap_lib.PoiArea\x12\x41\n\x0eparking_spaces\x18\n \x03(\x0b\x32).hdmap_lib.MapElements.ParkingSpacesEntry\x12H\n\x11ParkingSpaceNames\x18\x0b \x03(\x0b\x32-.hdmap_lib.MapElements.ParkingSpaceNamesEntry\x12\x30\n\x0fgirder_displays\x18\x0c \x03(\x0b\x32\x17.hdmap_lib.PolygonArrow\x1a=\n\nLanesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.hdmap_lib.Lane:\x02\x38\x01\x1a\x45\n\x0eJunctionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.hdmap_lib.Junction:\x02\x38\x01\x1aG\n\nLinesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.hdmap_lib.LineStringData:\x02\x38\x01\x1a\x41\n\x0cObjectsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.hdmap_lib.Object:\x02\x38\x01\x1a;\n\tPoisEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.hdmap_lib.Poi:\x02\x38\x01\x1aO\n\x13LaneArrowdatasEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.hdmap_lib.LaneArrowData:\x02\x38\x01\x1a\x37\n\x15PoiLaneRelationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1aM\n\x12ParkingSpacesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.hdmap_lib.ParkingSpace:\x02\x38\x01\x1a\x38\n\x16ParkingSpaceNamesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\\\n\x0bGetMapReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12(\n\x08map_unit\x18\x02 \x01(\x0b\x32\x16.hdmap_lib.MapElements\x12\x0f\n\x07map_md5\x18\x03 \x01(\t\"\xce\x01\n\x0cGirderStatus\x12\x0f\n\x07start_s\x18\x01 \x01(\x01\x12\r\n\x05\x65nd_s\x18\x02 \x01(\x01\x12\x35\n\x11girder_directions\x18\x03 \x03(\x0e\x32\x1a.hdmap_lib.GirderDirection\x12\x1c\n\rhas_this_area\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x13\n\x0bstatus_code\x18\x05 \x01(\x05\x12\x34\n\x10\x63hosen_direction\x18\x06 \x01(\x0e\x32\x1a.hdmap_lib.GirderDirection\"\xc1\x02\n\x06vessel\x12\x0e\n\x06head_x\x18\x01 \x01(\x01\x12\x0e\n\x06head_y\x18\x02 \x01(\x01\x12\x0e\n\x06rear_x\x18\x03 \x01(\x01\x12\x0e\n\x06rear_y\x18\x04 \x01(\x01\x12\x0c\n\x04uuid\x18\x05 \x01(\t\x12\x13\n\x0bhead_bridge\x18\x06 \x01(\t\x12\x14\n\x0cleave_bridge\x18\x07 \x01(\t\x12*\n\teast_area\x18\x08 \x01(\x0b\x32\x17.hdmap_lib.GirderStatus\x12\x32\n\x11\x65\x61st_working_area\x18\t \x01(\x0b\x32\x17.hdmap_lib.GirderStatus\x12\x32\n\x11west_working_area\x18\n \x01(\x0b\x32\x17.hdmap_lib.GirderStatus\x12*\n\twest_area\x18\x0b \x01(\x0b\x32\x17.hdmap_lib.GirderStatus\"3\n\rvessel_status\x12\"\n\x07vessels\x18\x01 \x03(\x0b\x32\x11.hdmap_lib.vessel\"\x86\x01\n\x11SetVesselsRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12/\n\rvessel_status\x18\x02 \x01(\x0b\x32\x18.hdmap_lib.vessel_status\x12\x16\n\x0e\x62usiness_scene\x18\x03 \x01(\t\x12\x14\n\x0c\x63lear_vessel\x18\x04 \x01(\x08\"<\n\x0fSetVesselsReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x15\n\rreload_status\x18\x02 \x01(\x08\"?\n\x11GetVesselsRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x16\n\x0e\x62usiness_scene\x18\x02 \x01(\t\"o\n\x0fGetVesselsReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x17\n\x0fis_exist_vessel\x18\x02 \x01(\x08\x12/\n\rvessel_status\x18\x03 \x01(\x0b\x32\x18.hdmap_lib.vessel_status\"N\n\x0eGetBaysRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x16\n\x0e\x62usiness_scene\x18\x02 \x01(\t\x12\x10\n\x08road_bay\x18\x03 \x01(\t\"8\n\x0cGetBaysReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\"_\n\x1bGetElementOnPositionRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x16\n\x0e\x62usiness_scene\x18\x02 \x01(\t\x12\t\n\x01x\x18\x03 \x01(\x01\x12\t\n\x01y\x18\x04 \x01(\x01\"\x92\x01\n\x19GetElementOnPositionReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x37\n\x04type\x18\x02 \x01(\x0e\x32).hdmap_lib.GetElementOnPositionReply.Type\"(\n\x04Type\x12\x08\n\x04LANE\x10\x01\x12\x0c\n\x08JUNCTION\x10\x02\x12\x08\n\x04NONE\x10\x03\",\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\r\n\x05index\x18\x03 \x01(\t\"e\n\x15GetBlockStatusRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x16\n\x0e\x62usiness_scene\x18\x02 \x01(\t\x12 \n\x06points\x18\x03 \x03(\x0b\x32\x10.hdmap_lib.Point\"q\n\x0bWrongStatus\x12\r\n\x05index\x18\x01 \x01(\t\x12)\n\x04type\x18\x02 \x01(\x0e\x32\x1b.hdmap_lib.WrongStatus.Type\"(\n\x04Type\x12\x08\n\x04LANE\x10\x01\x12\x0c\n\x08JUNCTION\x10\x02\x12\x08\n\x04NONE\x10\x03\"g\n\x13GetBlockStatusReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0e\n\x06status\x18\x02 \x01(\x08\x12,\n\x0cwrong_points\x18\x03 \x03(\x0b\x32\x16.hdmap_lib.WrongStatus\"0\n\x0cWorkingRange\x12\x10\n\x08\x66rom_pos\x18\x01 \x01(\x05\x12\x0e\n\x06to_pos\x18\x02 \x01(\x05\"\"\n\x0cWorkingLanes\x12\x12\n\nlane_index\x18\x01 \x03(\x05\"\x19\n\x05\x46\x65nce\x12\x10\n\x08position\x18\x01 \x03(\x05\"@\n\x08Obstacle\x12\x12\n\nlane_index\x18\x01 \x03(\x05\x12\x10\n\x08\x66rom_pos\x18\x02 \x01(\x05\x12\x0e\n\x06to_pos\x18\x03 \x01(\x05\"\x85\x03\n\x1fGetSuggestVesselPositionRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x16\n\x0e\x62usiness_scene\x18\x02 \x01(\t\x12.\n\rworking_range\x18\x03 \x01(\x0b\x32\x17.hdmap_lib.WorkingRange\x12=\n\x04side\x18\x04 \x01(\x0e\x32/.hdmap_lib.GetSuggestVesselPositionRequest.Side\x12.\n\rworking_lanes\x18\x05 \x01(\x0b\x32\x17.hdmap_lib.WorkingLanes\x12\x1f\n\x05\x66\x65nce\x18\x06 \x01(\x0b\x32\x10.hdmap_lib.Fence\x12)\n\x0chatch_covers\x18\x07 \x03(\x0b\x32\x13.hdmap_lib.Obstacle\x12&\n\tobstacles\x18\x08 \x03(\x0b\x32\x13.hdmap_lib.Obstacle\"#\n\x04Side\x12\x0c\n\x08PORTSIDE\x10\x01\x12\r\n\tSTARBOARD\x10\x02\"\xb1\x02\n\x1dGetSuggestVesselPositionReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12K\n\nhead_range\x18\x03 \x01(\x0b\x32\x37.hdmap_lib.GetSuggestVesselPositionReply.AvaliableRange\x12K\n\nrear_range\x18\x04 \x01(\x0b\x32\x37.hdmap_lib.GetSuggestVesselPositionReply.AvaliableRange\x12\x16\n\x0estatus_message\x18\x05 \x01(\t\x1a:\n\x0e\x41valiableRange\x12\x13\n\x0bupper_bound\x18\x01 \x01(\x01\x12\x13\n\x0blower_bound\x18\x02 \x01(\x01\"\x96\x01\n\x19GetElectronicFenceRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x16\n\x0e\x62usiness_scene\x18\x02 \x01(\t\x12\x12\n\nlock_names\x18\x03 \x03(\t\x12\x1b\n\x13\x66orward_extend_dist\x18\x04 \x01(\x01\x12\x1c\n\x14\x62\x61\x63kward_extend_dist\x18\x05 \x01(\x01\"\xc3\x01\n\x17GetElectronicFenceReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12M\n\x11\x65lectronic_fences\x18\x02 \x03(\x0b\x32\x32.hdmap_lib.GetElectronicFenceReply.ElectronicFence\x1a\x45\n\x0f\x45lectronicFence\x12\x10\n\x08poi_name\x18\x01 \x01(\t\x12 \n\x06points\x18\x02 \x03(\x0b\x32\x10.hdmap_lib.Point\"3\n\rPolygonPoints\x12\"\n\x06points\x18\x01 \x03(\x0b\x32\x12.hdmap_lib.Point3D\"D\n\x16GetYardJunctionRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x16\n\x0e\x62usiness_scene\x18\x02 \x01(\t\"\xd2\x01\n\x14GetYardJunctionReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12?\n\tjunctions\x18\x02 \x03(\x0b\x32,.hdmap_lib.GetYardJunctionReply.JunctionInfo\x1a\x65\n\x0cJunctionInfo\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x32\n\x10junction_polygon\x18\x02 \x01(\x0b\x32\x18.hdmap_lib.PolygonPoints\x12\x15\n\rjunction_name\x18\x03 \x01(\t\"\xcc\x01\n\x0e\x42lockPointPair\x12\'\n\rleft_up_point\x18\x01 \x01(\x0b\x32\x10.hdmap_lib.Point\x12,\n\x12right_bottom_point\x18\x02 \x01(\x0b\x32\x10.hdmap_lib.Point\x12\x0c\n\x04\x66lag\x18\x03 \x01(\t\x12(\n\x0eright_up_point\x18\x04 \x01(\x0b\x32\x10.hdmap_lib.Point\x12+\n\x11left_bottom_point\x18\x05 \x01(\x0b\x32\x10.hdmap_lib.Point\"\x7f\n\x1bGetRoutingBlockRangeRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x16\n\x0e\x62usiness_scene\x18\x02 \x01(\t\x12\x34\n\x11\x62lock_point_pairs\x18\x03 \x03(\x0b\x32\x19.hdmap_lib.BlockPointPair\"4\n\nBlockRange\x12&\n\x0c\x62lock_points\x18\x01 \x03(\x0b\x32\x10.hdmap_lib.Point\"M\n\x10\x42lockPointRanges\x12+\n\x0c\x62lock_ranges\x18\x01 \x03(\x0b\x32\x15.hdmap_lib.BlockRange\x12\x0c\n\x04\x66lag\x18\x02 \x01(\t\"h\n\x19GetRoutingBlockRangeReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x37\n\x12\x62lock_point_ranges\x18\x02 \x03(\x0b\x32\x1b.hdmap_lib.BlockPointRanges\"/\n\nBridgeMode\x12\x13\n\x0b\x62ridge_name\x18\x01 \x01(\t\x12\x0c\n\x04mode\x18\x02 \x01(\x05\"\x93\x01\n\x1bSetBridgeDrivingModeRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x16\n\x0e\x62usiness_scene\x18\x02 \x01(\t\x12\x1b\n\x13\x62ridge_driving_mode\x18\x03 \x01(\x05\x12+\n\x0c\x62ridge_modes\x18\x04 \x03(\x0b\x32\x15.hdmap_lib.BridgeMode\"C\n\x19SetBridgeDrivingModeReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x12\n\nset_status\x18\x02 \x01(\x08\"I\n\x1bGetBridgeDrivingModeRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x16\n\x0e\x62usiness_scene\x18\x02 \x01(\t\"l\n\x19GetBridgeDrivingModeReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0e\n\x06status\x18\x02 \x01(\x08\x12+\n\x0c\x62ridge_modes\x18\x03 \x03(\x0b\x32\x15.hdmap_lib.BridgeMode\"\xa6\x01\n\x18GetHdmapLibVesselRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x16\n\x0e\x62usiness_scene\x18\x02 \x01(\t\x12/\n\rsaved_vessels\x18\x03 \x01(\x0b\x32\x18.hdmap_lib.vessel_status\x12-\n\x0bnew_vessels\x18\x04 \x01(\x0b\x32\x18.hdmap_lib.vessel_status\"\xb5\x01\n\x16GetHdmapLibVesselReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12/\n\rmoved_vessels\x18\x02 \x01(\x0b\x32\x18.hdmap_lib.vessel_status\x12\x13\n\x0bstatus_code\x18\x03 \x01(\x05\x12\x16\n\x0estatus_message\x18\x04 \x01(\t\x12\x13\n\x0bsystem_prow\x18\x05 \x01(\x01\x12\x14\n\x0csystem_stern\x18\x06 \x01(\x01\"\xab\x01\n\x1dGetGirderDirectionModeRequest\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x16\n\x0e\x62usiness_scene\x18\x02 \x01(\t\x12/\n\rsaved_vessels\x18\x03 \x01(\x0b\x32\x18.hdmap_lib.vessel_status\x12-\n\x0bnew_vessels\x18\x04 \x01(\x0b\x32\x18.hdmap_lib.vessel_status\"o\n\x0cGirderAffect\x12\x14\n\x0c\x61\x66\x66\x65\x63t_level\x18\x01 \x01(\x05\x12\x13\n\x0b\x61\x66\x66\x65\x63t_uuid\x18\x02 \x01(\t\x12\x34\n\x10\x61\x66\x66\x65\x63t_direction\x18\x03 \x01(\x0e\x32\x1a.hdmap_lib.GirderDirection\"\xfa\x02\n\x1bGetGirderDirectionModeReply\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x13\n\x0bstatus_code\x18\x02 \x01(\x05\x12\x16\n\x0estatus_message\x18\x03 \x01(\t\x12*\n\teast_area\x18\x04 \x01(\x0b\x32\x17.hdmap_lib.GirderStatus\x12\x32\n\x11\x65\x61st_working_area\x18\x05 \x01(\x0b\x32\x17.hdmap_lib.GirderStatus\x12\x32\n\x11west_working_area\x18\x06 \x01(\x0b\x32\x17.hdmap_lib.GirderStatus\x12*\n\twest_area\x18\x07 \x01(\x0b\x32\x17.hdmap_lib.GirderStatus\x12,\n\x0b\x65\x61st_affect\x18\x08 \x01(\x0b\x32\x17.hdmap_lib.GirderAffect\x12,\n\x0bwest_affect\x18\t \x01(\x0b\x32\x17.hdmap_lib.GirderAffect*H\n\x0fGirderDirection\x12\n\n\x06NORMAL\x10\x01\x12\x0b\n\x07REVERSE\x10\x02\x12\r\n\tBOTH_EAST\x10\x03\x12\r\n\tBOTH_WEST\x10\x04\x32\xce\t\n\x08HdmapLib\x12<\n\x06GetMap\x12\x18.hdmap_lib.GetMapRequest\x1a\x16.hdmap_lib.GetMapReply\"\x00\x12H\n\nSetVessels\x12\x1c.hdmap_lib.SetVesselsRequest\x1a\x1a.hdmap_lib.SetVesselsReply\"\x00\x12H\n\nGetVessels\x12\x1c.hdmap_lib.GetVesselsRequest\x1a\x1a.hdmap_lib.GetVesselsReply\"\x00\x12\x66\n\x14GetElementOnPosition\x12&.hdmap_lib.GetElementOnPositionRequest\x1a$.hdmap_lib.GetElementOnPositionReply\"\x00\x12T\n\x0eGetBlockStatus\x12 .hdmap_lib.GetBlockStatusRequest\x1a\x1e.hdmap_lib.GetBlockStatusReply\"\x00\x12r\n\x18GetSuggestVesselPosition\x12*.hdmap_lib.GetSuggestVesselPositionRequest\x1a(.hdmap_lib.GetSuggestVesselPositionReply\"\x00\x12`\n\x12GetElectronicFence\x12$.hdmap_lib.GetElectronicFenceRequest\x1a\".hdmap_lib.GetElectronicFenceReply\"\x00\x12W\n\x0fGetYardJunction\x12!.hdmap_lib.GetYardJunctionRequest\x1a\x1f.hdmap_lib.GetYardJunctionReply\"\x00\x12\x66\n\x14GetRoutingBlockRange\x12&.hdmap_lib.GetRoutingBlockRangeRequest\x1a$.hdmap_lib.GetRoutingBlockRangeReply\"\x00\x12\x66\n\x14SetBridgeDrivingMode\x12&.hdmap_lib.SetBridgeDrivingModeRequest\x1a$.hdmap_lib.SetBridgeDrivingModeReply\"\x00\x12\x66\n\x14GetBridgeDrivingMode\x12&.hdmap_lib.GetBridgeDrivingModeRequest\x1a$.hdmap_lib.GetBridgeDrivingModeReply\"\x00\x12]\n\x11GetHdmapLibVessel\x12#.hdmap_lib.GetHdmapLibVesselRequest\x1a!.hdmap_lib.GetHdmapLibVesselReply\"\x00\x12l\n\x16GetGirderDirectionMode\x12(.hdmap_lib.GetGirderDirectionModeRequest\x1a&.hdmap_lib.GetGirderDirectionModeReply\"\x00\x42\x32\n\x19io.grpc.examples.hdmaplibB\rHdmapLibProtoP\x01\xa2\x02\x03HDL'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_lane__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_junction__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_object__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_poi__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_parking__space__pb2.DESCRIPTOR,])

_GIRDERDIRECTION = _descriptor.EnumDescriptor(
  name='GirderDirection',
  full_name='hdmap_lib.GirderDirection',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NORMAL', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REVERSE', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOTH_EAST', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOTH_WEST', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7518,
  serialized_end=7590,
)
_sym_db.RegisterEnumDescriptor(_GIRDERDIRECTION)

GirderDirection = enum_type_wrapper.EnumTypeWrapper(_GIRDERDIRECTION)
NORMAL = 1
REVERSE = 2
BOTH_EAST = 3
BOTH_WEST = 4


_LANEARROWDATA_TURNTYPE = _descriptor.EnumDescriptor(
  name='Turntype',
  full_name='hdmap_lib.LaneArrowData.Turntype',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_TURN', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_TURN', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_TURN', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_U_TURN', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_U_TURN', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=435,
  serialized_end=524,
)
_sym_db.RegisterEnumDescriptor(_LANEARROWDATA_TURNTYPE)

_GETELEMENTONPOSITIONREPLY_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='hdmap_lib.GetElementOnPositionReply.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LANE', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JUNCTION', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NONE', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3492,
  serialized_end=3532,
)
_sym_db.RegisterEnumDescriptor(_GETELEMENTONPOSITIONREPLY_TYPE)

_WRONGSTATUS_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='hdmap_lib.WrongStatus.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LANE', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JUNCTION', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NONE', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3492,
  serialized_end=3532,
)
_sym_db.RegisterEnumDescriptor(_WRONGSTATUS_TYPE)

_GETSUGGESTVESSELPOSITIONREQUEST_SIDE = _descriptor.EnumDescriptor(
  name='Side',
  full_name='hdmap_lib.GetSuggestVesselPositionRequest.Side',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PORTSIDE', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STARBOARD', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4437,
  serialized_end=4472,
)
_sym_db.RegisterEnumDescriptor(_GETSUGGESTVESSELPOSITIONREQUEST_SIDE)


_GETMAPREQUEST = _descriptor.Descriptor(
  name='GetMapRequest',
  full_name='hdmap_lib.GetMapRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetMapRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='business_scene', full_name='hdmap_lib.GetMapRequest.business_scene', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=262,
  serialized_end=321,
)


_LANEARROWDATA = _descriptor.Descriptor(
  name='LaneArrowData',
  full_name='hdmap_lib.LaneArrowData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='heading', full_name='hdmap_lib.LaneArrowData.heading', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x', full_name='hdmap_lib.LaneArrowData.x', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='hdmap_lib.LaneArrowData.y', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turn_types', full_name='hdmap_lib.LaneArrowData.turn_types', index=3,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LANEARROWDATA_TURNTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=324,
  serialized_end=524,
)


_POLYGONARROW = _descriptor.Descriptor(
  name='PolygonArrow',
  full_name='hdmap_lib.PolygonArrow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='hdmap_lib.PolygonArrow.points', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='center_x', full_name='hdmap_lib.PolygonArrow.center_x', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='center_y', full_name='hdmap_lib.PolygonArrow.center_y', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='hdmap_lib.PolygonArrow.heading', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=526,
  serialized_end=635,
)


_POIAREA = _descriptor.Descriptor(
  name='PoiArea',
  full_name='hdmap_lib.PoiArea',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='hdmap_lib.PoiArea.points', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='poi_name', full_name='hdmap_lib.PoiArea.poi_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x', full_name='hdmap_lib.PoiArea.x', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='hdmap_lib.PoiArea.y', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='hdmap_lib.PoiArea.heading', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='poi_type', full_name='hdmap_lib.PoiArea.poi_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=638,
  serialized_end=788,
)


_MAPELEMENTS_LANESENTRY = _descriptor.Descriptor(
  name='LanesEntry',
  full_name='hdmap_lib.MapElements.LanesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='hdmap_lib.MapElements.LanesEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='hdmap_lib.MapElements.LanesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1483,
  serialized_end=1544,
)

_MAPELEMENTS_JUNCTIONSENTRY = _descriptor.Descriptor(
  name='JunctionsEntry',
  full_name='hdmap_lib.MapElements.JunctionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='hdmap_lib.MapElements.JunctionsEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='hdmap_lib.MapElements.JunctionsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1546,
  serialized_end=1615,
)

_MAPELEMENTS_LINESENTRY = _descriptor.Descriptor(
  name='LinesEntry',
  full_name='hdmap_lib.MapElements.LinesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='hdmap_lib.MapElements.LinesEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='hdmap_lib.MapElements.LinesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1617,
  serialized_end=1688,
)

_MAPELEMENTS_OBJECTSENTRY = _descriptor.Descriptor(
  name='ObjectsEntry',
  full_name='hdmap_lib.MapElements.ObjectsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='hdmap_lib.MapElements.ObjectsEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='hdmap_lib.MapElements.ObjectsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1690,
  serialized_end=1755,
)

_MAPELEMENTS_POISENTRY = _descriptor.Descriptor(
  name='PoisEntry',
  full_name='hdmap_lib.MapElements.PoisEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='hdmap_lib.MapElements.PoisEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='hdmap_lib.MapElements.PoisEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1757,
  serialized_end=1816,
)

_MAPELEMENTS_LANEARROWDATASENTRY = _descriptor.Descriptor(
  name='LaneArrowdatasEntry',
  full_name='hdmap_lib.MapElements.LaneArrowdatasEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='hdmap_lib.MapElements.LaneArrowdatasEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='hdmap_lib.MapElements.LaneArrowdatasEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1818,
  serialized_end=1897,
)

_MAPELEMENTS_POILANERELATIONSENTRY = _descriptor.Descriptor(
  name='PoiLaneRelationsEntry',
  full_name='hdmap_lib.MapElements.PoiLaneRelationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='hdmap_lib.MapElements.PoiLaneRelationsEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='hdmap_lib.MapElements.PoiLaneRelationsEntry.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1899,
  serialized_end=1954,
)

_MAPELEMENTS_PARKINGSPACESENTRY = _descriptor.Descriptor(
  name='ParkingSpacesEntry',
  full_name='hdmap_lib.MapElements.ParkingSpacesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='hdmap_lib.MapElements.ParkingSpacesEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='hdmap_lib.MapElements.ParkingSpacesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1956,
  serialized_end=2033,
)

_MAPELEMENTS_PARKINGSPACENAMESENTRY = _descriptor.Descriptor(
  name='ParkingSpaceNamesEntry',
  full_name='hdmap_lib.MapElements.ParkingSpaceNamesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='hdmap_lib.MapElements.ParkingSpaceNamesEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='hdmap_lib.MapElements.ParkingSpaceNamesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2035,
  serialized_end=2091,
)

_MAPELEMENTS = _descriptor.Descriptor(
  name='MapElements',
  full_name='hdmap_lib.MapElements',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lanes', full_name='hdmap_lib.MapElements.lanes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junctions', full_name='hdmap_lib.MapElements.junctions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lines', full_name='hdmap_lib.MapElements.lines', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='objects', full_name='hdmap_lib.MapElements.objects', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pois', full_name='hdmap_lib.MapElements.pois', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='LaneArrowdatas', full_name='hdmap_lib.MapElements.LaneArrowdatas', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='PoiLaneRelations', full_name='hdmap_lib.MapElements.PoiLaneRelations', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arrow_lanes', full_name='hdmap_lib.MapElements.arrow_lanes', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='poi_areas', full_name='hdmap_lib.MapElements.poi_areas', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_spaces', full_name='hdmap_lib.MapElements.parking_spaces', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ParkingSpaceNames', full_name='hdmap_lib.MapElements.ParkingSpaceNames', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='girder_displays', full_name='hdmap_lib.MapElements.girder_displays', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MAPELEMENTS_LANESENTRY, _MAPELEMENTS_JUNCTIONSENTRY, _MAPELEMENTS_LINESENTRY, _MAPELEMENTS_OBJECTSENTRY, _MAPELEMENTS_POISENTRY, _MAPELEMENTS_LANEARROWDATASENTRY, _MAPELEMENTS_POILANERELATIONSENTRY, _MAPELEMENTS_PARKINGSPACESENTRY, _MAPELEMENTS_PARKINGSPACENAMESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=791,
  serialized_end=2091,
)


_GETMAPREPLY = _descriptor.Descriptor(
  name='GetMapReply',
  full_name='hdmap_lib.GetMapReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetMapReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_unit', full_name='hdmap_lib.GetMapReply.map_unit', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_md5', full_name='hdmap_lib.GetMapReply.map_md5', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2093,
  serialized_end=2185,
)


_GIRDERSTATUS = _descriptor.Descriptor(
  name='GirderStatus',
  full_name='hdmap_lib.GirderStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_s', full_name='hdmap_lib.GirderStatus.start_s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_s', full_name='hdmap_lib.GirderStatus.end_s', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='girder_directions', full_name='hdmap_lib.GirderStatus.girder_directions', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_this_area', full_name='hdmap_lib.GirderStatus.has_this_area', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code', full_name='hdmap_lib.GirderStatus.status_code', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chosen_direction', full_name='hdmap_lib.GirderStatus.chosen_direction', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2188,
  serialized_end=2394,
)


_VESSEL = _descriptor.Descriptor(
  name='vessel',
  full_name='hdmap_lib.vessel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='head_x', full_name='hdmap_lib.vessel.head_x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='head_y', full_name='hdmap_lib.vessel.head_y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_x', full_name='hdmap_lib.vessel.rear_x', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_y', full_name='hdmap_lib.vessel.rear_y', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='hdmap_lib.vessel.uuid', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='head_bridge', full_name='hdmap_lib.vessel.head_bridge', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leave_bridge', full_name='hdmap_lib.vessel.leave_bridge', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='east_area', full_name='hdmap_lib.vessel.east_area', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='east_working_area', full_name='hdmap_lib.vessel.east_working_area', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='west_working_area', full_name='hdmap_lib.vessel.west_working_area', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='west_area', full_name='hdmap_lib.vessel.west_area', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2397,
  serialized_end=2718,
)


_VESSEL_STATUS = _descriptor.Descriptor(
  name='vessel_status',
  full_name='hdmap_lib.vessel_status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vessels', full_name='hdmap_lib.vessel_status.vessels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2720,
  serialized_end=2771,
)


_SETVESSELSREQUEST = _descriptor.Descriptor(
  name='SetVesselsRequest',
  full_name='hdmap_lib.SetVesselsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.SetVesselsRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vessel_status', full_name='hdmap_lib.SetVesselsRequest.vessel_status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='business_scene', full_name='hdmap_lib.SetVesselsRequest.business_scene', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_vessel', full_name='hdmap_lib.SetVesselsRequest.clear_vessel', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2774,
  serialized_end=2908,
)


_SETVESSELSREPLY = _descriptor.Descriptor(
  name='SetVesselsReply',
  full_name='hdmap_lib.SetVesselsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.SetVesselsReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reload_status', full_name='hdmap_lib.SetVesselsReply.reload_status', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2910,
  serialized_end=2970,
)


_GETVESSELSREQUEST = _descriptor.Descriptor(
  name='GetVesselsRequest',
  full_name='hdmap_lib.GetVesselsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetVesselsRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='business_scene', full_name='hdmap_lib.GetVesselsRequest.business_scene', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2972,
  serialized_end=3035,
)


_GETVESSELSREPLY = _descriptor.Descriptor(
  name='GetVesselsReply',
  full_name='hdmap_lib.GetVesselsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetVesselsReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_exist_vessel', full_name='hdmap_lib.GetVesselsReply.is_exist_vessel', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vessel_status', full_name='hdmap_lib.GetVesselsReply.vessel_status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3037,
  serialized_end=3148,
)


_GETBAYSREQUEST = _descriptor.Descriptor(
  name='GetBaysRequest',
  full_name='hdmap_lib.GetBaysRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetBaysRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='business_scene', full_name='hdmap_lib.GetBaysRequest.business_scene', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='road_bay', full_name='hdmap_lib.GetBaysRequest.road_bay', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3150,
  serialized_end=3228,
)


_GETBAYSREPLY = _descriptor.Descriptor(
  name='GetBaysReply',
  full_name='hdmap_lib.GetBaysReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetBaysReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x', full_name='hdmap_lib.GetBaysReply.x', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='hdmap_lib.GetBaysReply.y', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3230,
  serialized_end=3286,
)


_GETELEMENTONPOSITIONREQUEST = _descriptor.Descriptor(
  name='GetElementOnPositionRequest',
  full_name='hdmap_lib.GetElementOnPositionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetElementOnPositionRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='business_scene', full_name='hdmap_lib.GetElementOnPositionRequest.business_scene', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x', full_name='hdmap_lib.GetElementOnPositionRequest.x', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='hdmap_lib.GetElementOnPositionRequest.y', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3288,
  serialized_end=3383,
)


_GETELEMENTONPOSITIONREPLY = _descriptor.Descriptor(
  name='GetElementOnPositionReply',
  full_name='hdmap_lib.GetElementOnPositionReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetElementOnPositionReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='hdmap_lib.GetElementOnPositionReply.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETELEMENTONPOSITIONREPLY_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3386,
  serialized_end=3532,
)


_POINT = _descriptor.Descriptor(
  name='Point',
  full_name='hdmap_lib.Point',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='hdmap_lib.Point.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='hdmap_lib.Point.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='hdmap_lib.Point.index', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3534,
  serialized_end=3578,
)


_GETBLOCKSTATUSREQUEST = _descriptor.Descriptor(
  name='GetBlockStatusRequest',
  full_name='hdmap_lib.GetBlockStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetBlockStatusRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='business_scene', full_name='hdmap_lib.GetBlockStatusRequest.business_scene', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='points', full_name='hdmap_lib.GetBlockStatusRequest.points', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3580,
  serialized_end=3681,
)


_WRONGSTATUS = _descriptor.Descriptor(
  name='WrongStatus',
  full_name='hdmap_lib.WrongStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='hdmap_lib.WrongStatus.index', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='hdmap_lib.WrongStatus.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _WRONGSTATUS_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3683,
  serialized_end=3796,
)


_GETBLOCKSTATUSREPLY = _descriptor.Descriptor(
  name='GetBlockStatusReply',
  full_name='hdmap_lib.GetBlockStatusReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetBlockStatusReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='hdmap_lib.GetBlockStatusReply.status', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wrong_points', full_name='hdmap_lib.GetBlockStatusReply.wrong_points', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3798,
  serialized_end=3901,
)


_WORKINGRANGE = _descriptor.Descriptor(
  name='WorkingRange',
  full_name='hdmap_lib.WorkingRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_pos', full_name='hdmap_lib.WorkingRange.from_pos', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_pos', full_name='hdmap_lib.WorkingRange.to_pos', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3903,
  serialized_end=3951,
)


_WORKINGLANES = _descriptor.Descriptor(
  name='WorkingLanes',
  full_name='hdmap_lib.WorkingLanes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_index', full_name='hdmap_lib.WorkingLanes.lane_index', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3953,
  serialized_end=3987,
)


_FENCE = _descriptor.Descriptor(
  name='Fence',
  full_name='hdmap_lib.Fence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='hdmap_lib.Fence.position', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3989,
  serialized_end=4014,
)


_OBSTACLE = _descriptor.Descriptor(
  name='Obstacle',
  full_name='hdmap_lib.Obstacle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_index', full_name='hdmap_lib.Obstacle.lane_index', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_pos', full_name='hdmap_lib.Obstacle.from_pos', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_pos', full_name='hdmap_lib.Obstacle.to_pos', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4016,
  serialized_end=4080,
)


_GETSUGGESTVESSELPOSITIONREQUEST = _descriptor.Descriptor(
  name='GetSuggestVesselPositionRequest',
  full_name='hdmap_lib.GetSuggestVesselPositionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetSuggestVesselPositionRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='business_scene', full_name='hdmap_lib.GetSuggestVesselPositionRequest.business_scene', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='working_range', full_name='hdmap_lib.GetSuggestVesselPositionRequest.working_range', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='side', full_name='hdmap_lib.GetSuggestVesselPositionRequest.side', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='working_lanes', full_name='hdmap_lib.GetSuggestVesselPositionRequest.working_lanes', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fence', full_name='hdmap_lib.GetSuggestVesselPositionRequest.fence', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hatch_covers', full_name='hdmap_lib.GetSuggestVesselPositionRequest.hatch_covers', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacles', full_name='hdmap_lib.GetSuggestVesselPositionRequest.obstacles', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETSUGGESTVESSELPOSITIONREQUEST_SIDE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4083,
  serialized_end=4472,
)


_GETSUGGESTVESSELPOSITIONREPLY_AVALIABLERANGE = _descriptor.Descriptor(
  name='AvaliableRange',
  full_name='hdmap_lib.GetSuggestVesselPositionReply.AvaliableRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upper_bound', full_name='hdmap_lib.GetSuggestVesselPositionReply.AvaliableRange.upper_bound', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lower_bound', full_name='hdmap_lib.GetSuggestVesselPositionReply.AvaliableRange.lower_bound', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4722,
  serialized_end=4780,
)

_GETSUGGESTVESSELPOSITIONREPLY = _descriptor.Descriptor(
  name='GetSuggestVesselPositionReply',
  full_name='hdmap_lib.GetSuggestVesselPositionReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetSuggestVesselPositionReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='hdmap_lib.GetSuggestVesselPositionReply.status', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='head_range', full_name='hdmap_lib.GetSuggestVesselPositionReply.head_range', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rear_range', full_name='hdmap_lib.GetSuggestVesselPositionReply.rear_range', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_message', full_name='hdmap_lib.GetSuggestVesselPositionReply.status_message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETSUGGESTVESSELPOSITIONREPLY_AVALIABLERANGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4475,
  serialized_end=4780,
)


_GETELECTRONICFENCEREQUEST = _descriptor.Descriptor(
  name='GetElectronicFenceRequest',
  full_name='hdmap_lib.GetElectronicFenceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetElectronicFenceRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='business_scene', full_name='hdmap_lib.GetElectronicFenceRequest.business_scene', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lock_names', full_name='hdmap_lib.GetElectronicFenceRequest.lock_names', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forward_extend_dist', full_name='hdmap_lib.GetElectronicFenceRequest.forward_extend_dist', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backward_extend_dist', full_name='hdmap_lib.GetElectronicFenceRequest.backward_extend_dist', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4783,
  serialized_end=4933,
)


_GETELECTRONICFENCEREPLY_ELECTRONICFENCE = _descriptor.Descriptor(
  name='ElectronicFence',
  full_name='hdmap_lib.GetElectronicFenceReply.ElectronicFence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='poi_name', full_name='hdmap_lib.GetElectronicFenceReply.ElectronicFence.poi_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='points', full_name='hdmap_lib.GetElectronicFenceReply.ElectronicFence.points', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5062,
  serialized_end=5131,
)

_GETELECTRONICFENCEREPLY = _descriptor.Descriptor(
  name='GetElectronicFenceReply',
  full_name='hdmap_lib.GetElectronicFenceReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetElectronicFenceReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='electronic_fences', full_name='hdmap_lib.GetElectronicFenceReply.electronic_fences', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETELECTRONICFENCEREPLY_ELECTRONICFENCE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4936,
  serialized_end=5131,
)


_POLYGONPOINTS = _descriptor.Descriptor(
  name='PolygonPoints',
  full_name='hdmap_lib.PolygonPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='hdmap_lib.PolygonPoints.points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5133,
  serialized_end=5184,
)


_GETYARDJUNCTIONREQUEST = _descriptor.Descriptor(
  name='GetYardJunctionRequest',
  full_name='hdmap_lib.GetYardJunctionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetYardJunctionRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='business_scene', full_name='hdmap_lib.GetYardJunctionRequest.business_scene', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5186,
  serialized_end=5254,
)


_GETYARDJUNCTIONREPLY_JUNCTIONINFO = _descriptor.Descriptor(
  name='JunctionInfo',
  full_name='hdmap_lib.GetYardJunctionReply.JunctionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.GetYardJunctionReply.JunctionInfo.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_polygon', full_name='hdmap_lib.GetYardJunctionReply.JunctionInfo.junction_polygon', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_name', full_name='hdmap_lib.GetYardJunctionReply.JunctionInfo.junction_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5366,
  serialized_end=5467,
)

_GETYARDJUNCTIONREPLY = _descriptor.Descriptor(
  name='GetYardJunctionReply',
  full_name='hdmap_lib.GetYardJunctionReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetYardJunctionReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junctions', full_name='hdmap_lib.GetYardJunctionReply.junctions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETYARDJUNCTIONREPLY_JUNCTIONINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5257,
  serialized_end=5467,
)


_BLOCKPOINTPAIR = _descriptor.Descriptor(
  name='BlockPointPair',
  full_name='hdmap_lib.BlockPointPair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='left_up_point', full_name='hdmap_lib.BlockPointPair.left_up_point', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_bottom_point', full_name='hdmap_lib.BlockPointPair.right_bottom_point', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flag', full_name='hdmap_lib.BlockPointPair.flag', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_up_point', full_name='hdmap_lib.BlockPointPair.right_up_point', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_bottom_point', full_name='hdmap_lib.BlockPointPair.left_bottom_point', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5470,
  serialized_end=5674,
)


_GETROUTINGBLOCKRANGEREQUEST = _descriptor.Descriptor(
  name='GetRoutingBlockRangeRequest',
  full_name='hdmap_lib.GetRoutingBlockRangeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetRoutingBlockRangeRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='business_scene', full_name='hdmap_lib.GetRoutingBlockRangeRequest.business_scene', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_point_pairs', full_name='hdmap_lib.GetRoutingBlockRangeRequest.block_point_pairs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5676,
  serialized_end=5803,
)


_BLOCKRANGE = _descriptor.Descriptor(
  name='BlockRange',
  full_name='hdmap_lib.BlockRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_points', full_name='hdmap_lib.BlockRange.block_points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5805,
  serialized_end=5857,
)


_BLOCKPOINTRANGES = _descriptor.Descriptor(
  name='BlockPointRanges',
  full_name='hdmap_lib.BlockPointRanges',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_ranges', full_name='hdmap_lib.BlockPointRanges.block_ranges', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flag', full_name='hdmap_lib.BlockPointRanges.flag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5859,
  serialized_end=5936,
)


_GETROUTINGBLOCKRANGEREPLY = _descriptor.Descriptor(
  name='GetRoutingBlockRangeReply',
  full_name='hdmap_lib.GetRoutingBlockRangeReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetRoutingBlockRangeReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_point_ranges', full_name='hdmap_lib.GetRoutingBlockRangeReply.block_point_ranges', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5938,
  serialized_end=6042,
)


_BRIDGEMODE = _descriptor.Descriptor(
  name='BridgeMode',
  full_name='hdmap_lib.BridgeMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bridge_name', full_name='hdmap_lib.BridgeMode.bridge_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='hdmap_lib.BridgeMode.mode', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6044,
  serialized_end=6091,
)


_SETBRIDGEDRIVINGMODEREQUEST = _descriptor.Descriptor(
  name='SetBridgeDrivingModeRequest',
  full_name='hdmap_lib.SetBridgeDrivingModeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.SetBridgeDrivingModeRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='business_scene', full_name='hdmap_lib.SetBridgeDrivingModeRequest.business_scene', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bridge_driving_mode', full_name='hdmap_lib.SetBridgeDrivingModeRequest.bridge_driving_mode', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bridge_modes', full_name='hdmap_lib.SetBridgeDrivingModeRequest.bridge_modes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6094,
  serialized_end=6241,
)


_SETBRIDGEDRIVINGMODEREPLY = _descriptor.Descriptor(
  name='SetBridgeDrivingModeReply',
  full_name='hdmap_lib.SetBridgeDrivingModeReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.SetBridgeDrivingModeReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_status', full_name='hdmap_lib.SetBridgeDrivingModeReply.set_status', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6243,
  serialized_end=6310,
)


_GETBRIDGEDRIVINGMODEREQUEST = _descriptor.Descriptor(
  name='GetBridgeDrivingModeRequest',
  full_name='hdmap_lib.GetBridgeDrivingModeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetBridgeDrivingModeRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='business_scene', full_name='hdmap_lib.GetBridgeDrivingModeRequest.business_scene', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6312,
  serialized_end=6385,
)


_GETBRIDGEDRIVINGMODEREPLY = _descriptor.Descriptor(
  name='GetBridgeDrivingModeReply',
  full_name='hdmap_lib.GetBridgeDrivingModeReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetBridgeDrivingModeReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='hdmap_lib.GetBridgeDrivingModeReply.status', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bridge_modes', full_name='hdmap_lib.GetBridgeDrivingModeReply.bridge_modes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6387,
  serialized_end=6495,
)


_GETHDMAPLIBVESSELREQUEST = _descriptor.Descriptor(
  name='GetHdmapLibVesselRequest',
  full_name='hdmap_lib.GetHdmapLibVesselRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetHdmapLibVesselRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='business_scene', full_name='hdmap_lib.GetHdmapLibVesselRequest.business_scene', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='saved_vessels', full_name='hdmap_lib.GetHdmapLibVesselRequest.saved_vessels', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_vessels', full_name='hdmap_lib.GetHdmapLibVesselRequest.new_vessels', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6498,
  serialized_end=6664,
)


_GETHDMAPLIBVESSELREPLY = _descriptor.Descriptor(
  name='GetHdmapLibVesselReply',
  full_name='hdmap_lib.GetHdmapLibVesselReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetHdmapLibVesselReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='moved_vessels', full_name='hdmap_lib.GetHdmapLibVesselReply.moved_vessels', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code', full_name='hdmap_lib.GetHdmapLibVesselReply.status_code', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_message', full_name='hdmap_lib.GetHdmapLibVesselReply.status_message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='system_prow', full_name='hdmap_lib.GetHdmapLibVesselReply.system_prow', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='system_stern', full_name='hdmap_lib.GetHdmapLibVesselReply.system_stern', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6667,
  serialized_end=6848,
)


_GETGIRDERDIRECTIONMODEREQUEST = _descriptor.Descriptor(
  name='GetGirderDirectionModeRequest',
  full_name='hdmap_lib.GetGirderDirectionModeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetGirderDirectionModeRequest.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='business_scene', full_name='hdmap_lib.GetGirderDirectionModeRequest.business_scene', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='saved_vessels', full_name='hdmap_lib.GetGirderDirectionModeRequest.saved_vessels', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_vessels', full_name='hdmap_lib.GetGirderDirectionModeRequest.new_vessels', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6851,
  serialized_end=7022,
)


_GIRDERAFFECT = _descriptor.Descriptor(
  name='GirderAffect',
  full_name='hdmap_lib.GirderAffect',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='affect_level', full_name='hdmap_lib.GirderAffect.affect_level', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='affect_uuid', full_name='hdmap_lib.GirderAffect.affect_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='affect_direction', full_name='hdmap_lib.GirderAffect.affect_direction', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7024,
  serialized_end=7135,
)


_GETGIRDERDIRECTIONMODEREPLY = _descriptor.Descriptor(
  name='GetGirderDirectionModeReply',
  full_name='hdmap_lib.GetGirderDirectionModeReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='hdmap_lib.GetGirderDirectionModeReply.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_code', full_name='hdmap_lib.GetGirderDirectionModeReply.status_code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_message', full_name='hdmap_lib.GetGirderDirectionModeReply.status_message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='east_area', full_name='hdmap_lib.GetGirderDirectionModeReply.east_area', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='east_working_area', full_name='hdmap_lib.GetGirderDirectionModeReply.east_working_area', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='west_working_area', full_name='hdmap_lib.GetGirderDirectionModeReply.west_working_area', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='west_area', full_name='hdmap_lib.GetGirderDirectionModeReply.west_area', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='east_affect', full_name='hdmap_lib.GetGirderDirectionModeReply.east_affect', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='west_affect', full_name='hdmap_lib.GetGirderDirectionModeReply.west_affect', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7138,
  serialized_end=7516,
)

_LANEARROWDATA.fields_by_name['turn_types'].enum_type = _LANEARROWDATA_TURNTYPE
_LANEARROWDATA_TURNTYPE.containing_type = _LANEARROWDATA
_POLYGONARROW.fields_by_name['points'].message_type = _POLYGONPOINTS
_POIAREA.fields_by_name['points'].message_type = _POLYGONPOINTS
_POIAREA.fields_by_name['poi_type'].enum_type = proto_dot_hdmap__lib_dot_proto_dot_poi__pb2._POI_POITYPE
_MAPELEMENTS_LANESENTRY.fields_by_name['value'].message_type = proto_dot_hdmap__lib_dot_proto_dot_lane__pb2._LANE
_MAPELEMENTS_LANESENTRY.containing_type = _MAPELEMENTS
_MAPELEMENTS_JUNCTIONSENTRY.fields_by_name['value'].message_type = proto_dot_hdmap__lib_dot_proto_dot_junction__pb2._JUNCTION
_MAPELEMENTS_JUNCTIONSENTRY.containing_type = _MAPELEMENTS
_MAPELEMENTS_LINESENTRY.fields_by_name['value'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._LINESTRINGDATA
_MAPELEMENTS_LINESENTRY.containing_type = _MAPELEMENTS
_MAPELEMENTS_OBJECTSENTRY.fields_by_name['value'].message_type = proto_dot_hdmap__lib_dot_proto_dot_object__pb2._OBJECT
_MAPELEMENTS_OBJECTSENTRY.containing_type = _MAPELEMENTS
_MAPELEMENTS_POISENTRY.fields_by_name['value'].message_type = proto_dot_hdmap__lib_dot_proto_dot_poi__pb2._POI
_MAPELEMENTS_POISENTRY.containing_type = _MAPELEMENTS
_MAPELEMENTS_LANEARROWDATASENTRY.fields_by_name['value'].message_type = _LANEARROWDATA
_MAPELEMENTS_LANEARROWDATASENTRY.containing_type = _MAPELEMENTS
_MAPELEMENTS_POILANERELATIONSENTRY.containing_type = _MAPELEMENTS
_MAPELEMENTS_PARKINGSPACESENTRY.fields_by_name['value'].message_type = proto_dot_hdmap__lib_dot_proto_dot_parking__space__pb2._PARKINGSPACE
_MAPELEMENTS_PARKINGSPACESENTRY.containing_type = _MAPELEMENTS
_MAPELEMENTS_PARKINGSPACENAMESENTRY.containing_type = _MAPELEMENTS
_MAPELEMENTS.fields_by_name['lanes'].message_type = _MAPELEMENTS_LANESENTRY
_MAPELEMENTS.fields_by_name['junctions'].message_type = _MAPELEMENTS_JUNCTIONSENTRY
_MAPELEMENTS.fields_by_name['lines'].message_type = _MAPELEMENTS_LINESENTRY
_MAPELEMENTS.fields_by_name['objects'].message_type = _MAPELEMENTS_OBJECTSENTRY
_MAPELEMENTS.fields_by_name['pois'].message_type = _MAPELEMENTS_POISENTRY
_MAPELEMENTS.fields_by_name['LaneArrowdatas'].message_type = _MAPELEMENTS_LANEARROWDATASENTRY
_MAPELEMENTS.fields_by_name['PoiLaneRelations'].message_type = _MAPELEMENTS_POILANERELATIONSENTRY
_MAPELEMENTS.fields_by_name['arrow_lanes'].message_type = _LANEARROWDATA
_MAPELEMENTS.fields_by_name['poi_areas'].message_type = _POIAREA
_MAPELEMENTS.fields_by_name['parking_spaces'].message_type = _MAPELEMENTS_PARKINGSPACESENTRY
_MAPELEMENTS.fields_by_name['ParkingSpaceNames'].message_type = _MAPELEMENTS_PARKINGSPACENAMESENTRY
_MAPELEMENTS.fields_by_name['girder_displays'].message_type = _POLYGONARROW
_GETMAPREPLY.fields_by_name['map_unit'].message_type = _MAPELEMENTS
_GIRDERSTATUS.fields_by_name['girder_directions'].enum_type = _GIRDERDIRECTION
_GIRDERSTATUS.fields_by_name['chosen_direction'].enum_type = _GIRDERDIRECTION
_VESSEL.fields_by_name['east_area'].message_type = _GIRDERSTATUS
_VESSEL.fields_by_name['east_working_area'].message_type = _GIRDERSTATUS
_VESSEL.fields_by_name['west_working_area'].message_type = _GIRDERSTATUS
_VESSEL.fields_by_name['west_area'].message_type = _GIRDERSTATUS
_VESSEL_STATUS.fields_by_name['vessels'].message_type = _VESSEL
_SETVESSELSREQUEST.fields_by_name['vessel_status'].message_type = _VESSEL_STATUS
_GETVESSELSREPLY.fields_by_name['vessel_status'].message_type = _VESSEL_STATUS
_GETELEMENTONPOSITIONREPLY.fields_by_name['type'].enum_type = _GETELEMENTONPOSITIONREPLY_TYPE
_GETELEMENTONPOSITIONREPLY_TYPE.containing_type = _GETELEMENTONPOSITIONREPLY
_GETBLOCKSTATUSREQUEST.fields_by_name['points'].message_type = _POINT
_WRONGSTATUS.fields_by_name['type'].enum_type = _WRONGSTATUS_TYPE
_WRONGSTATUS_TYPE.containing_type = _WRONGSTATUS
_GETBLOCKSTATUSREPLY.fields_by_name['wrong_points'].message_type = _WRONGSTATUS
_GETSUGGESTVESSELPOSITIONREQUEST.fields_by_name['working_range'].message_type = _WORKINGRANGE
_GETSUGGESTVESSELPOSITIONREQUEST.fields_by_name['side'].enum_type = _GETSUGGESTVESSELPOSITIONREQUEST_SIDE
_GETSUGGESTVESSELPOSITIONREQUEST.fields_by_name['working_lanes'].message_type = _WORKINGLANES
_GETSUGGESTVESSELPOSITIONREQUEST.fields_by_name['fence'].message_type = _FENCE
_GETSUGGESTVESSELPOSITIONREQUEST.fields_by_name['hatch_covers'].message_type = _OBSTACLE
_GETSUGGESTVESSELPOSITIONREQUEST.fields_by_name['obstacles'].message_type = _OBSTACLE
_GETSUGGESTVESSELPOSITIONREQUEST_SIDE.containing_type = _GETSUGGESTVESSELPOSITIONREQUEST
_GETSUGGESTVESSELPOSITIONREPLY_AVALIABLERANGE.containing_type = _GETSUGGESTVESSELPOSITIONREPLY
_GETSUGGESTVESSELPOSITIONREPLY.fields_by_name['head_range'].message_type = _GETSUGGESTVESSELPOSITIONREPLY_AVALIABLERANGE
_GETSUGGESTVESSELPOSITIONREPLY.fields_by_name['rear_range'].message_type = _GETSUGGESTVESSELPOSITIONREPLY_AVALIABLERANGE
_GETELECTRONICFENCEREPLY_ELECTRONICFENCE.fields_by_name['points'].message_type = _POINT
_GETELECTRONICFENCEREPLY_ELECTRONICFENCE.containing_type = _GETELECTRONICFENCEREPLY
_GETELECTRONICFENCEREPLY.fields_by_name['electronic_fences'].message_type = _GETELECTRONICFENCEREPLY_ELECTRONICFENCE
_POLYGONPOINTS.fields_by_name['points'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._POINT3D
_GETYARDJUNCTIONREPLY_JUNCTIONINFO.fields_by_name['junction_polygon'].message_type = _POLYGONPOINTS
_GETYARDJUNCTIONREPLY_JUNCTIONINFO.containing_type = _GETYARDJUNCTIONREPLY
_GETYARDJUNCTIONREPLY.fields_by_name['junctions'].message_type = _GETYARDJUNCTIONREPLY_JUNCTIONINFO
_BLOCKPOINTPAIR.fields_by_name['left_up_point'].message_type = _POINT
_BLOCKPOINTPAIR.fields_by_name['right_bottom_point'].message_type = _POINT
_BLOCKPOINTPAIR.fields_by_name['right_up_point'].message_type = _POINT
_BLOCKPOINTPAIR.fields_by_name['left_bottom_point'].message_type = _POINT
_GETROUTINGBLOCKRANGEREQUEST.fields_by_name['block_point_pairs'].message_type = _BLOCKPOINTPAIR
_BLOCKRANGE.fields_by_name['block_points'].message_type = _POINT
_BLOCKPOINTRANGES.fields_by_name['block_ranges'].message_type = _BLOCKRANGE
_GETROUTINGBLOCKRANGEREPLY.fields_by_name['block_point_ranges'].message_type = _BLOCKPOINTRANGES
_SETBRIDGEDRIVINGMODEREQUEST.fields_by_name['bridge_modes'].message_type = _BRIDGEMODE
_GETBRIDGEDRIVINGMODEREPLY.fields_by_name['bridge_modes'].message_type = _BRIDGEMODE
_GETHDMAPLIBVESSELREQUEST.fields_by_name['saved_vessels'].message_type = _VESSEL_STATUS
_GETHDMAPLIBVESSELREQUEST.fields_by_name['new_vessels'].message_type = _VESSEL_STATUS
_GETHDMAPLIBVESSELREPLY.fields_by_name['moved_vessels'].message_type = _VESSEL_STATUS
_GETGIRDERDIRECTIONMODEREQUEST.fields_by_name['saved_vessels'].message_type = _VESSEL_STATUS
_GETGIRDERDIRECTIONMODEREQUEST.fields_by_name['new_vessels'].message_type = _VESSEL_STATUS
_GIRDERAFFECT.fields_by_name['affect_direction'].enum_type = _GIRDERDIRECTION
_GETGIRDERDIRECTIONMODEREPLY.fields_by_name['east_area'].message_type = _GIRDERSTATUS
_GETGIRDERDIRECTIONMODEREPLY.fields_by_name['east_working_area'].message_type = _GIRDERSTATUS
_GETGIRDERDIRECTIONMODEREPLY.fields_by_name['west_working_area'].message_type = _GIRDERSTATUS
_GETGIRDERDIRECTIONMODEREPLY.fields_by_name['west_area'].message_type = _GIRDERSTATUS
_GETGIRDERDIRECTIONMODEREPLY.fields_by_name['east_affect'].message_type = _GIRDERAFFECT
_GETGIRDERDIRECTIONMODEREPLY.fields_by_name['west_affect'].message_type = _GIRDERAFFECT
DESCRIPTOR.message_types_by_name['GetMapRequest'] = _GETMAPREQUEST
DESCRIPTOR.message_types_by_name['LaneArrowData'] = _LANEARROWDATA
DESCRIPTOR.message_types_by_name['PolygonArrow'] = _POLYGONARROW
DESCRIPTOR.message_types_by_name['PoiArea'] = _POIAREA
DESCRIPTOR.message_types_by_name['MapElements'] = _MAPELEMENTS
DESCRIPTOR.message_types_by_name['GetMapReply'] = _GETMAPREPLY
DESCRIPTOR.message_types_by_name['GirderStatus'] = _GIRDERSTATUS
DESCRIPTOR.message_types_by_name['vessel'] = _VESSEL
DESCRIPTOR.message_types_by_name['vessel_status'] = _VESSEL_STATUS
DESCRIPTOR.message_types_by_name['SetVesselsRequest'] = _SETVESSELSREQUEST
DESCRIPTOR.message_types_by_name['SetVesselsReply'] = _SETVESSELSREPLY
DESCRIPTOR.message_types_by_name['GetVesselsRequest'] = _GETVESSELSREQUEST
DESCRIPTOR.message_types_by_name['GetVesselsReply'] = _GETVESSELSREPLY
DESCRIPTOR.message_types_by_name['GetBaysRequest'] = _GETBAYSREQUEST
DESCRIPTOR.message_types_by_name['GetBaysReply'] = _GETBAYSREPLY
DESCRIPTOR.message_types_by_name['GetElementOnPositionRequest'] = _GETELEMENTONPOSITIONREQUEST
DESCRIPTOR.message_types_by_name['GetElementOnPositionReply'] = _GETELEMENTONPOSITIONREPLY
DESCRIPTOR.message_types_by_name['Point'] = _POINT
DESCRIPTOR.message_types_by_name['GetBlockStatusRequest'] = _GETBLOCKSTATUSREQUEST
DESCRIPTOR.message_types_by_name['WrongStatus'] = _WRONGSTATUS
DESCRIPTOR.message_types_by_name['GetBlockStatusReply'] = _GETBLOCKSTATUSREPLY
DESCRIPTOR.message_types_by_name['WorkingRange'] = _WORKINGRANGE
DESCRIPTOR.message_types_by_name['WorkingLanes'] = _WORKINGLANES
DESCRIPTOR.message_types_by_name['Fence'] = _FENCE
DESCRIPTOR.message_types_by_name['Obstacle'] = _OBSTACLE
DESCRIPTOR.message_types_by_name['GetSuggestVesselPositionRequest'] = _GETSUGGESTVESSELPOSITIONREQUEST
DESCRIPTOR.message_types_by_name['GetSuggestVesselPositionReply'] = _GETSUGGESTVESSELPOSITIONREPLY
DESCRIPTOR.message_types_by_name['GetElectronicFenceRequest'] = _GETELECTRONICFENCEREQUEST
DESCRIPTOR.message_types_by_name['GetElectronicFenceReply'] = _GETELECTRONICFENCEREPLY
DESCRIPTOR.message_types_by_name['PolygonPoints'] = _POLYGONPOINTS
DESCRIPTOR.message_types_by_name['GetYardJunctionRequest'] = _GETYARDJUNCTIONREQUEST
DESCRIPTOR.message_types_by_name['GetYardJunctionReply'] = _GETYARDJUNCTIONREPLY
DESCRIPTOR.message_types_by_name['BlockPointPair'] = _BLOCKPOINTPAIR
DESCRIPTOR.message_types_by_name['GetRoutingBlockRangeRequest'] = _GETROUTINGBLOCKRANGEREQUEST
DESCRIPTOR.message_types_by_name['BlockRange'] = _BLOCKRANGE
DESCRIPTOR.message_types_by_name['BlockPointRanges'] = _BLOCKPOINTRANGES
DESCRIPTOR.message_types_by_name['GetRoutingBlockRangeReply'] = _GETROUTINGBLOCKRANGEREPLY
DESCRIPTOR.message_types_by_name['BridgeMode'] = _BRIDGEMODE
DESCRIPTOR.message_types_by_name['SetBridgeDrivingModeRequest'] = _SETBRIDGEDRIVINGMODEREQUEST
DESCRIPTOR.message_types_by_name['SetBridgeDrivingModeReply'] = _SETBRIDGEDRIVINGMODEREPLY
DESCRIPTOR.message_types_by_name['GetBridgeDrivingModeRequest'] = _GETBRIDGEDRIVINGMODEREQUEST
DESCRIPTOR.message_types_by_name['GetBridgeDrivingModeReply'] = _GETBRIDGEDRIVINGMODEREPLY
DESCRIPTOR.message_types_by_name['GetHdmapLibVesselRequest'] = _GETHDMAPLIBVESSELREQUEST
DESCRIPTOR.message_types_by_name['GetHdmapLibVesselReply'] = _GETHDMAPLIBVESSELREPLY
DESCRIPTOR.message_types_by_name['GetGirderDirectionModeRequest'] = _GETGIRDERDIRECTIONMODEREQUEST
DESCRIPTOR.message_types_by_name['GirderAffect'] = _GIRDERAFFECT
DESCRIPTOR.message_types_by_name['GetGirderDirectionModeReply'] = _GETGIRDERDIRECTIONMODEREPLY
DESCRIPTOR.enum_types_by_name['GirderDirection'] = _GIRDERDIRECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetMapRequest = _reflection.GeneratedProtocolMessageType('GetMapRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMAPREQUEST,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetMapRequest)
  })
_sym_db.RegisterMessage(GetMapRequest)

LaneArrowData = _reflection.GeneratedProtocolMessageType('LaneArrowData', (_message.Message,), {
  'DESCRIPTOR' : _LANEARROWDATA,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LaneArrowData)
  })
_sym_db.RegisterMessage(LaneArrowData)

PolygonArrow = _reflection.GeneratedProtocolMessageType('PolygonArrow', (_message.Message,), {
  'DESCRIPTOR' : _POLYGONARROW,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.PolygonArrow)
  })
_sym_db.RegisterMessage(PolygonArrow)

PoiArea = _reflection.GeneratedProtocolMessageType('PoiArea', (_message.Message,), {
  'DESCRIPTOR' : _POIAREA,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.PoiArea)
  })
_sym_db.RegisterMessage(PoiArea)

MapElements = _reflection.GeneratedProtocolMessageType('MapElements', (_message.Message,), {

  'LanesEntry' : _reflection.GeneratedProtocolMessageType('LanesEntry', (_message.Message,), {
    'DESCRIPTOR' : _MAPELEMENTS_LANESENTRY,
    '__module__' : 'proto.grpc.hdmaplib_pb2'
    # @@protoc_insertion_point(class_scope:hdmap_lib.MapElements.LanesEntry)
    })
  ,

  'JunctionsEntry' : _reflection.GeneratedProtocolMessageType('JunctionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _MAPELEMENTS_JUNCTIONSENTRY,
    '__module__' : 'proto.grpc.hdmaplib_pb2'
    # @@protoc_insertion_point(class_scope:hdmap_lib.MapElements.JunctionsEntry)
    })
  ,

  'LinesEntry' : _reflection.GeneratedProtocolMessageType('LinesEntry', (_message.Message,), {
    'DESCRIPTOR' : _MAPELEMENTS_LINESENTRY,
    '__module__' : 'proto.grpc.hdmaplib_pb2'
    # @@protoc_insertion_point(class_scope:hdmap_lib.MapElements.LinesEntry)
    })
  ,

  'ObjectsEntry' : _reflection.GeneratedProtocolMessageType('ObjectsEntry', (_message.Message,), {
    'DESCRIPTOR' : _MAPELEMENTS_OBJECTSENTRY,
    '__module__' : 'proto.grpc.hdmaplib_pb2'
    # @@protoc_insertion_point(class_scope:hdmap_lib.MapElements.ObjectsEntry)
    })
  ,

  'PoisEntry' : _reflection.GeneratedProtocolMessageType('PoisEntry', (_message.Message,), {
    'DESCRIPTOR' : _MAPELEMENTS_POISENTRY,
    '__module__' : 'proto.grpc.hdmaplib_pb2'
    # @@protoc_insertion_point(class_scope:hdmap_lib.MapElements.PoisEntry)
    })
  ,

  'LaneArrowdatasEntry' : _reflection.GeneratedProtocolMessageType('LaneArrowdatasEntry', (_message.Message,), {
    'DESCRIPTOR' : _MAPELEMENTS_LANEARROWDATASENTRY,
    '__module__' : 'proto.grpc.hdmaplib_pb2'
    # @@protoc_insertion_point(class_scope:hdmap_lib.MapElements.LaneArrowdatasEntry)
    })
  ,

  'PoiLaneRelationsEntry' : _reflection.GeneratedProtocolMessageType('PoiLaneRelationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _MAPELEMENTS_POILANERELATIONSENTRY,
    '__module__' : 'proto.grpc.hdmaplib_pb2'
    # @@protoc_insertion_point(class_scope:hdmap_lib.MapElements.PoiLaneRelationsEntry)
    })
  ,

  'ParkingSpacesEntry' : _reflection.GeneratedProtocolMessageType('ParkingSpacesEntry', (_message.Message,), {
    'DESCRIPTOR' : _MAPELEMENTS_PARKINGSPACESENTRY,
    '__module__' : 'proto.grpc.hdmaplib_pb2'
    # @@protoc_insertion_point(class_scope:hdmap_lib.MapElements.ParkingSpacesEntry)
    })
  ,

  'ParkingSpaceNamesEntry' : _reflection.GeneratedProtocolMessageType('ParkingSpaceNamesEntry', (_message.Message,), {
    'DESCRIPTOR' : _MAPELEMENTS_PARKINGSPACENAMESENTRY,
    '__module__' : 'proto.grpc.hdmaplib_pb2'
    # @@protoc_insertion_point(class_scope:hdmap_lib.MapElements.ParkingSpaceNamesEntry)
    })
  ,
  'DESCRIPTOR' : _MAPELEMENTS,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.MapElements)
  })
_sym_db.RegisterMessage(MapElements)
_sym_db.RegisterMessage(MapElements.LanesEntry)
_sym_db.RegisterMessage(MapElements.JunctionsEntry)
_sym_db.RegisterMessage(MapElements.LinesEntry)
_sym_db.RegisterMessage(MapElements.ObjectsEntry)
_sym_db.RegisterMessage(MapElements.PoisEntry)
_sym_db.RegisterMessage(MapElements.LaneArrowdatasEntry)
_sym_db.RegisterMessage(MapElements.PoiLaneRelationsEntry)
_sym_db.RegisterMessage(MapElements.ParkingSpacesEntry)
_sym_db.RegisterMessage(MapElements.ParkingSpaceNamesEntry)

GetMapReply = _reflection.GeneratedProtocolMessageType('GetMapReply', (_message.Message,), {
  'DESCRIPTOR' : _GETMAPREPLY,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetMapReply)
  })
_sym_db.RegisterMessage(GetMapReply)

GirderStatus = _reflection.GeneratedProtocolMessageType('GirderStatus', (_message.Message,), {
  'DESCRIPTOR' : _GIRDERSTATUS,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GirderStatus)
  })
_sym_db.RegisterMessage(GirderStatus)

vessel = _reflection.GeneratedProtocolMessageType('vessel', (_message.Message,), {
  'DESCRIPTOR' : _VESSEL,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.vessel)
  })
_sym_db.RegisterMessage(vessel)

vessel_status = _reflection.GeneratedProtocolMessageType('vessel_status', (_message.Message,), {
  'DESCRIPTOR' : _VESSEL_STATUS,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.vessel_status)
  })
_sym_db.RegisterMessage(vessel_status)

SetVesselsRequest = _reflection.GeneratedProtocolMessageType('SetVesselsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETVESSELSREQUEST,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.SetVesselsRequest)
  })
_sym_db.RegisterMessage(SetVesselsRequest)

SetVesselsReply = _reflection.GeneratedProtocolMessageType('SetVesselsReply', (_message.Message,), {
  'DESCRIPTOR' : _SETVESSELSREPLY,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.SetVesselsReply)
  })
_sym_db.RegisterMessage(SetVesselsReply)

GetVesselsRequest = _reflection.GeneratedProtocolMessageType('GetVesselsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVESSELSREQUEST,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetVesselsRequest)
  })
_sym_db.RegisterMessage(GetVesselsRequest)

GetVesselsReply = _reflection.GeneratedProtocolMessageType('GetVesselsReply', (_message.Message,), {
  'DESCRIPTOR' : _GETVESSELSREPLY,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetVesselsReply)
  })
_sym_db.RegisterMessage(GetVesselsReply)

GetBaysRequest = _reflection.GeneratedProtocolMessageType('GetBaysRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBAYSREQUEST,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetBaysRequest)
  })
_sym_db.RegisterMessage(GetBaysRequest)

GetBaysReply = _reflection.GeneratedProtocolMessageType('GetBaysReply', (_message.Message,), {
  'DESCRIPTOR' : _GETBAYSREPLY,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetBaysReply)
  })
_sym_db.RegisterMessage(GetBaysReply)

GetElementOnPositionRequest = _reflection.GeneratedProtocolMessageType('GetElementOnPositionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETELEMENTONPOSITIONREQUEST,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetElementOnPositionRequest)
  })
_sym_db.RegisterMessage(GetElementOnPositionRequest)

GetElementOnPositionReply = _reflection.GeneratedProtocolMessageType('GetElementOnPositionReply', (_message.Message,), {
  'DESCRIPTOR' : _GETELEMENTONPOSITIONREPLY,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetElementOnPositionReply)
  })
_sym_db.RegisterMessage(GetElementOnPositionReply)

Point = _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {
  'DESCRIPTOR' : _POINT,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Point)
  })
_sym_db.RegisterMessage(Point)

GetBlockStatusRequest = _reflection.GeneratedProtocolMessageType('GetBlockStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKSTATUSREQUEST,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetBlockStatusRequest)
  })
_sym_db.RegisterMessage(GetBlockStatusRequest)

WrongStatus = _reflection.GeneratedProtocolMessageType('WrongStatus', (_message.Message,), {
  'DESCRIPTOR' : _WRONGSTATUS,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.WrongStatus)
  })
_sym_db.RegisterMessage(WrongStatus)

GetBlockStatusReply = _reflection.GeneratedProtocolMessageType('GetBlockStatusReply', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKSTATUSREPLY,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetBlockStatusReply)
  })
_sym_db.RegisterMessage(GetBlockStatusReply)

WorkingRange = _reflection.GeneratedProtocolMessageType('WorkingRange', (_message.Message,), {
  'DESCRIPTOR' : _WORKINGRANGE,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.WorkingRange)
  })
_sym_db.RegisterMessage(WorkingRange)

WorkingLanes = _reflection.GeneratedProtocolMessageType('WorkingLanes', (_message.Message,), {
  'DESCRIPTOR' : _WORKINGLANES,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.WorkingLanes)
  })
_sym_db.RegisterMessage(WorkingLanes)

Fence = _reflection.GeneratedProtocolMessageType('Fence', (_message.Message,), {
  'DESCRIPTOR' : _FENCE,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Fence)
  })
_sym_db.RegisterMessage(Fence)

Obstacle = _reflection.GeneratedProtocolMessageType('Obstacle', (_message.Message,), {
  'DESCRIPTOR' : _OBSTACLE,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Obstacle)
  })
_sym_db.RegisterMessage(Obstacle)

GetSuggestVesselPositionRequest = _reflection.GeneratedProtocolMessageType('GetSuggestVesselPositionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSUGGESTVESSELPOSITIONREQUEST,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetSuggestVesselPositionRequest)
  })
_sym_db.RegisterMessage(GetSuggestVesselPositionRequest)

GetSuggestVesselPositionReply = _reflection.GeneratedProtocolMessageType('GetSuggestVesselPositionReply', (_message.Message,), {

  'AvaliableRange' : _reflection.GeneratedProtocolMessageType('AvaliableRange', (_message.Message,), {
    'DESCRIPTOR' : _GETSUGGESTVESSELPOSITIONREPLY_AVALIABLERANGE,
    '__module__' : 'proto.grpc.hdmaplib_pb2'
    # @@protoc_insertion_point(class_scope:hdmap_lib.GetSuggestVesselPositionReply.AvaliableRange)
    })
  ,
  'DESCRIPTOR' : _GETSUGGESTVESSELPOSITIONREPLY,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetSuggestVesselPositionReply)
  })
_sym_db.RegisterMessage(GetSuggestVesselPositionReply)
_sym_db.RegisterMessage(GetSuggestVesselPositionReply.AvaliableRange)

GetElectronicFenceRequest = _reflection.GeneratedProtocolMessageType('GetElectronicFenceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETELECTRONICFENCEREQUEST,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetElectronicFenceRequest)
  })
_sym_db.RegisterMessage(GetElectronicFenceRequest)

GetElectronicFenceReply = _reflection.GeneratedProtocolMessageType('GetElectronicFenceReply', (_message.Message,), {

  'ElectronicFence' : _reflection.GeneratedProtocolMessageType('ElectronicFence', (_message.Message,), {
    'DESCRIPTOR' : _GETELECTRONICFENCEREPLY_ELECTRONICFENCE,
    '__module__' : 'proto.grpc.hdmaplib_pb2'
    # @@protoc_insertion_point(class_scope:hdmap_lib.GetElectronicFenceReply.ElectronicFence)
    })
  ,
  'DESCRIPTOR' : _GETELECTRONICFENCEREPLY,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetElectronicFenceReply)
  })
_sym_db.RegisterMessage(GetElectronicFenceReply)
_sym_db.RegisterMessage(GetElectronicFenceReply.ElectronicFence)

PolygonPoints = _reflection.GeneratedProtocolMessageType('PolygonPoints', (_message.Message,), {
  'DESCRIPTOR' : _POLYGONPOINTS,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.PolygonPoints)
  })
_sym_db.RegisterMessage(PolygonPoints)

GetYardJunctionRequest = _reflection.GeneratedProtocolMessageType('GetYardJunctionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETYARDJUNCTIONREQUEST,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetYardJunctionRequest)
  })
_sym_db.RegisterMessage(GetYardJunctionRequest)

GetYardJunctionReply = _reflection.GeneratedProtocolMessageType('GetYardJunctionReply', (_message.Message,), {

  'JunctionInfo' : _reflection.GeneratedProtocolMessageType('JunctionInfo', (_message.Message,), {
    'DESCRIPTOR' : _GETYARDJUNCTIONREPLY_JUNCTIONINFO,
    '__module__' : 'proto.grpc.hdmaplib_pb2'
    # @@protoc_insertion_point(class_scope:hdmap_lib.GetYardJunctionReply.JunctionInfo)
    })
  ,
  'DESCRIPTOR' : _GETYARDJUNCTIONREPLY,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetYardJunctionReply)
  })
_sym_db.RegisterMessage(GetYardJunctionReply)
_sym_db.RegisterMessage(GetYardJunctionReply.JunctionInfo)

BlockPointPair = _reflection.GeneratedProtocolMessageType('BlockPointPair', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKPOINTPAIR,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.BlockPointPair)
  })
_sym_db.RegisterMessage(BlockPointPair)

GetRoutingBlockRangeRequest = _reflection.GeneratedProtocolMessageType('GetRoutingBlockRangeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETROUTINGBLOCKRANGEREQUEST,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetRoutingBlockRangeRequest)
  })
_sym_db.RegisterMessage(GetRoutingBlockRangeRequest)

BlockRange = _reflection.GeneratedProtocolMessageType('BlockRange', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKRANGE,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.BlockRange)
  })
_sym_db.RegisterMessage(BlockRange)

BlockPointRanges = _reflection.GeneratedProtocolMessageType('BlockPointRanges', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKPOINTRANGES,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.BlockPointRanges)
  })
_sym_db.RegisterMessage(BlockPointRanges)

GetRoutingBlockRangeReply = _reflection.GeneratedProtocolMessageType('GetRoutingBlockRangeReply', (_message.Message,), {
  'DESCRIPTOR' : _GETROUTINGBLOCKRANGEREPLY,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetRoutingBlockRangeReply)
  })
_sym_db.RegisterMessage(GetRoutingBlockRangeReply)

BridgeMode = _reflection.GeneratedProtocolMessageType('BridgeMode', (_message.Message,), {
  'DESCRIPTOR' : _BRIDGEMODE,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.BridgeMode)
  })
_sym_db.RegisterMessage(BridgeMode)

SetBridgeDrivingModeRequest = _reflection.GeneratedProtocolMessageType('SetBridgeDrivingModeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETBRIDGEDRIVINGMODEREQUEST,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.SetBridgeDrivingModeRequest)
  })
_sym_db.RegisterMessage(SetBridgeDrivingModeRequest)

SetBridgeDrivingModeReply = _reflection.GeneratedProtocolMessageType('SetBridgeDrivingModeReply', (_message.Message,), {
  'DESCRIPTOR' : _SETBRIDGEDRIVINGMODEREPLY,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.SetBridgeDrivingModeReply)
  })
_sym_db.RegisterMessage(SetBridgeDrivingModeReply)

GetBridgeDrivingModeRequest = _reflection.GeneratedProtocolMessageType('GetBridgeDrivingModeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBRIDGEDRIVINGMODEREQUEST,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetBridgeDrivingModeRequest)
  })
_sym_db.RegisterMessage(GetBridgeDrivingModeRequest)

GetBridgeDrivingModeReply = _reflection.GeneratedProtocolMessageType('GetBridgeDrivingModeReply', (_message.Message,), {
  'DESCRIPTOR' : _GETBRIDGEDRIVINGMODEREPLY,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetBridgeDrivingModeReply)
  })
_sym_db.RegisterMessage(GetBridgeDrivingModeReply)

GetHdmapLibVesselRequest = _reflection.GeneratedProtocolMessageType('GetHdmapLibVesselRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETHDMAPLIBVESSELREQUEST,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetHdmapLibVesselRequest)
  })
_sym_db.RegisterMessage(GetHdmapLibVesselRequest)

GetHdmapLibVesselReply = _reflection.GeneratedProtocolMessageType('GetHdmapLibVesselReply', (_message.Message,), {
  'DESCRIPTOR' : _GETHDMAPLIBVESSELREPLY,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetHdmapLibVesselReply)
  })
_sym_db.RegisterMessage(GetHdmapLibVesselReply)

GetGirderDirectionModeRequest = _reflection.GeneratedProtocolMessageType('GetGirderDirectionModeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETGIRDERDIRECTIONMODEREQUEST,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetGirderDirectionModeRequest)
  })
_sym_db.RegisterMessage(GetGirderDirectionModeRequest)

GirderAffect = _reflection.GeneratedProtocolMessageType('GirderAffect', (_message.Message,), {
  'DESCRIPTOR' : _GIRDERAFFECT,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GirderAffect)
  })
_sym_db.RegisterMessage(GirderAffect)

GetGirderDirectionModeReply = _reflection.GeneratedProtocolMessageType('GetGirderDirectionModeReply', (_message.Message,), {
  'DESCRIPTOR' : _GETGIRDERDIRECTIONMODEREPLY,
  '__module__' : 'proto.grpc.hdmaplib_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.GetGirderDirectionModeReply)
  })
_sym_db.RegisterMessage(GetGirderDirectionModeReply)


DESCRIPTOR._options = None
_MAPELEMENTS_LANESENTRY._options = None
_MAPELEMENTS_JUNCTIONSENTRY._options = None
_MAPELEMENTS_LINESENTRY._options = None
_MAPELEMENTS_OBJECTSENTRY._options = None
_MAPELEMENTS_POISENTRY._options = None
_MAPELEMENTS_LANEARROWDATASENTRY._options = None
_MAPELEMENTS_POILANERELATIONSENTRY._options = None
_MAPELEMENTS_PARKINGSPACESENTRY._options = None
_MAPELEMENTS_PARKINGSPACENAMESENTRY._options = None

_HDMAPLIB = _descriptor.ServiceDescriptor(
  name='HdmapLib',
  full_name='hdmap_lib.HdmapLib',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=7593,
  serialized_end=8823,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetMap',
    full_name='hdmap_lib.HdmapLib.GetMap',
    index=0,
    containing_service=None,
    input_type=_GETMAPREQUEST,
    output_type=_GETMAPREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetVessels',
    full_name='hdmap_lib.HdmapLib.SetVessels',
    index=1,
    containing_service=None,
    input_type=_SETVESSELSREQUEST,
    output_type=_SETVESSELSREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetVessels',
    full_name='hdmap_lib.HdmapLib.GetVessels',
    index=2,
    containing_service=None,
    input_type=_GETVESSELSREQUEST,
    output_type=_GETVESSELSREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetElementOnPosition',
    full_name='hdmap_lib.HdmapLib.GetElementOnPosition',
    index=3,
    containing_service=None,
    input_type=_GETELEMENTONPOSITIONREQUEST,
    output_type=_GETELEMENTONPOSITIONREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBlockStatus',
    full_name='hdmap_lib.HdmapLib.GetBlockStatus',
    index=4,
    containing_service=None,
    input_type=_GETBLOCKSTATUSREQUEST,
    output_type=_GETBLOCKSTATUSREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSuggestVesselPosition',
    full_name='hdmap_lib.HdmapLib.GetSuggestVesselPosition',
    index=5,
    containing_service=None,
    input_type=_GETSUGGESTVESSELPOSITIONREQUEST,
    output_type=_GETSUGGESTVESSELPOSITIONREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetElectronicFence',
    full_name='hdmap_lib.HdmapLib.GetElectronicFence',
    index=6,
    containing_service=None,
    input_type=_GETELECTRONICFENCEREQUEST,
    output_type=_GETELECTRONICFENCEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetYardJunction',
    full_name='hdmap_lib.HdmapLib.GetYardJunction',
    index=7,
    containing_service=None,
    input_type=_GETYARDJUNCTIONREQUEST,
    output_type=_GETYARDJUNCTIONREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRoutingBlockRange',
    full_name='hdmap_lib.HdmapLib.GetRoutingBlockRange',
    index=8,
    containing_service=None,
    input_type=_GETROUTINGBLOCKRANGEREQUEST,
    output_type=_GETROUTINGBLOCKRANGEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetBridgeDrivingMode',
    full_name='hdmap_lib.HdmapLib.SetBridgeDrivingMode',
    index=9,
    containing_service=None,
    input_type=_SETBRIDGEDRIVINGMODEREQUEST,
    output_type=_SETBRIDGEDRIVINGMODEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBridgeDrivingMode',
    full_name='hdmap_lib.HdmapLib.GetBridgeDrivingMode',
    index=10,
    containing_service=None,
    input_type=_GETBRIDGEDRIVINGMODEREQUEST,
    output_type=_GETBRIDGEDRIVINGMODEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetHdmapLibVessel',
    full_name='hdmap_lib.HdmapLib.GetHdmapLibVessel',
    index=11,
    containing_service=None,
    input_type=_GETHDMAPLIBVESSELREQUEST,
    output_type=_GETHDMAPLIBVESSELREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetGirderDirectionMode',
    full_name='hdmap_lib.HdmapLib.GetGirderDirectionMode',
    index=12,
    containing_service=None,
    input_type=_GETGIRDERDIRECTIONMODEREQUEST,
    output_type=_GETGIRDERDIRECTIONMODEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_HDMAPLIB)

DESCRIPTOR.services_by_name['HdmapLib'] = _HDMAPLIB

# @@protoc_insertion_point(module_scope)
